@@ -25,6 +25,7 @@ import inotifyx
 
 from .safeINotifier import SafeINotifier
 from .datasetIngestor import DatasetIngestor
+from .pathConverter import PathConverter
 from .logger import get_logger
 
 
@@ -56,6 +57,31 @@ class DatasetWatcher(threading.Thread):
 
         #: (:obj:`dict` <:obj:`str`, `any`>) ingestor configuration
         self.__config = configuration or {}
+
+        #: (:obj:`str`) core path
+        self.__corepath = meta.get("corePath", None)
+        #: (:obj:`dict` <:obj:`str`, :obj:`str`>) core notify path dict
+        self.__core_notify_path = {}
+        #: (:obj:`dict` <:obj:`str`, :obj:`str`>) notify core path dict
+        self.__notify_core_path = {}
+
+        #: (:obj:`str`) beamtime path
+        self.__bpath = os.path.split(beamtimefile)[0]
+
+        #: (:obj:`bool`) use core path
+        self.__usecorepath = False
+        if "use_corepath_as_scandir" in self.__config.keys():
+            try:
+                self.__usecorepath = bool(
+                    self.__config["use_corepath_as_scandir"])
+            except Exception as e:
+                get_logger().warning('%s' % (str(e)))
+
+        #: (:class:`scingestor.datasetWatcher.DatasetWatcher`) use core path
+        self.__conv = PathConverter(
+            self.__corepath, self.__bpath,
+            self.__usecorepath and self.__corepath)
+
         #: (:obj:`str`) file with a dataset list
         self.__dsfile = dsfile
         #: (:obj:`str`) file with a ingested dataset list
@@ -67,18 +93,18 @@ class DatasetWatcher(threading.Thread):
         #: (:obj:`dict` <:obj:`int`, :obj:`str`>) watch description paths
         self.__wd_to_path = {}
         #: (:obj:`dict` <:obj:`int`, :obj:`str`>)
-        #                               beamtime watch description paths
+        #:                              beamtime watch description paths
         self.__wd_to_queue = {}
 
         #: (:obj:`float`) timeout value for inotifyx get events in s
         self.__timeout = 0.01
         #: (:obj:`float`) max count of recheck the dataset list
-        self.__maxcounter = 100
+        self.__recheck_dslist_interval = 1000
 
-        if "max_request_tries_number" in self.__config.keys():
+        if "recheck_dataset_list_interval" in self.__config.keys():
             try:
-                self.__maxcounter = int(
-                    self.__config["max_request_tries_number"])
+                self.__recheck_dslist_interval = int(
+                    self.__config["recheck_dataset_list_interval"])
             except Exception as e:
                 get_logger().warning('%s' % (str(e)))
 
@@ -95,14 +121,53 @@ class DatasetWatcher(threading.Thread):
                 get_logger().warning('%s' % (str(e)))
 
         #: (:class:`scingestor.datasetIngestor.DatasetIngestor`)
-        #  dataset ingestor
+        #: dataset ingestor
         self.__ingestor = DatasetIngestor(
-            configuration, path, dsfile, idsfile, meta, beamtimefile)
+            configuration, path, dsfile, idsfile, meta,
+            self.__conv.to_core(beamtimefile))
+
+    def __to_core(self, path):
+        """ converts notify path to core path
+
+        :param path: notify path
+        :type path: :obj:`str`
+        :returns: core path
+        :rtype: :obj:`str`
+        """
+        if not self.__usecorepath or not self.__corepath:
+            return path
+        if path in self.__notify_core_path.keys():
+            return self.__notify_core_path[path]
+        if path.startswith(self.__bpath):
+            cpath = os.self.__corepath + path[len(self.__bpath):]
+            self.__notify_core_path[path] = cpath
+            self.__core_notify_path[cpath] = path
+            return cpath
+        return path
+
+    def __from_core(self, path):
+        """ converts core path to notify path
+
+        :param path: core path
+        :type path: :obj:`str`
+        :returns: notify path
+        :rtype: :obj:`str`
+        """
+        if not self.__usecorepath or not self.__corepath:
+            return path
+        if path in self.__core_notify_path.keys():
+            return self.__core_notify_path[path]
+        if path.startswith(self.__corepath):
+            bpath = os.self.__bpath + path[len(self.__corepath):]
+            self.__core_notify_path[path] = bpath
+            self.__notify_core_path[bpath] = path
+            return bpath
+        return path
 
     def _start_notifier(self, path):
         """ start notifier
 
-        :param path: beamtime file subpath
+        :param path: beamtime file sub directory
         :type path: :obj:`str`
         """
         self.__notifier = SafeINotifier()
@@ -116,7 +181,7 @@ class DatasetWatcher(threading.Thread):
         """
         try:
             wqueue, watch_descriptor = self.__notifier.add_watch(
-                path,
+                self.__conv.from_core(path),
                 inotifyx.IN_ALL_EVENTS |
                 inotifyx.IN_MODIFY |
                 inotifyx.IN_OPEN |
@@ -186,7 +251,7 @@ class DatasetWatcher(threading.Thread):
                         # get_logger().info(
                         #     'Ds: %s %s %s' % (event.name,
                         #                       event.masks,
-                        #                       self.__wd_to_path[qid]))
+                        #                       self._w_maid_to_path[qid]))
                         get_logger().debug(
                             'Ds: %s %s %s' % (event.name,
                                               event.masks,
@@ -202,6 +267,7 @@ class DatasetWatcher(threading.Thread):
                             if ffn is not None and ffn == self.__dsfile:
                                 get_logger().debug(
                                     'DatasetWatcher: Changed %s' % ffn)
+                                time.sleep(self.__delay)
                                 try:
                                     self.__ingestor.check_list()
                                 except Exception as e:
@@ -216,34 +282,37 @@ class DatasetWatcher(threading.Thread):
                                    ffn == self.__dsfile:
                                     get_logger().debug(
                                         'DatasetWatcher: Changed %s' % ffn)
+                                    time.sleep(self.__delay)
                                     try:
                                         self.__ingestor.check_list()
                                     except Exception as e:
                                         get_logger().warning(str(e))
                                         continue
 
-                if counter == self.__maxcounter:
-                    # if inotify does not work
-                    counter = 0
-                    # get_logger().info(
-                    #     'DatasetWatcher: Re-check dataset list after %s s'
-                    #     % self.__maxcounter)
-                    get_logger().debug(
-                        'DatasetWatcher: Re-check dataset list after %s s'
-                        % self.__maxcounter)
-                    try:
-                        self.__ingestor.check_list()
-                    except Exception as e:
-                        get_logger().warning(str(e))
-                        continue
-                elif self.__maxcounter > counter:
-                    get_logger().debug(
-                        'DatasetWatcher: increase counter %s/%s ' %
-                        (counter, self.__maxcounter))
-                    # get_logger().info(
-                    #     'DatasetWatcher: increase counter %s/%s ' %
-                    #     (counter, self.__maxcounter))
-                    counter += 1
+                if self.__recheck_dslist_interval > 0:
+                    if counter == self.__recheck_dslist_interval:
+                        # if inotify does not work
+                        counter = 0
+                        # get_logger().info(
+                        #   'DatasetWatcher: Re-check dataset list after %s s'
+                        #     % self.__recheck_dslist_interval)
+                        get_logger().debug(
+                            'DatasetWatcher: '
+                            'Re-check dataset list after %s s'
+                            % self.__recheck_dslist_interval)
+                        try:
+                            self.__ingestor.check_list()
+                        except Exception as e:
+                            get_logger().warning(str(e))
+                            continue
+                    elif self.__recheck_dslist_interval > counter:
+                        get_logger().debug(
+                            'DatasetWatcher: increase counter %s/%s ' %
+                            (counter, self.__recheck_dslist_interval))
+                        # GET_logger().info(
+                        #     'DatasetWatcher: increase counter %s/%s ' %
+                        #     (counter, self.__recheck_dslist_interval))
+                        counter += 1
 
                 if self.__ingestor.waiting_datasets():
                     time.sleep(self.__delay)
